@@ -197,7 +197,7 @@ typedef int lives_pgid_t;
 #define DESKTOP_ICON_DIR "/share/icons/hicolor/48x48/apps"
 #define DATA_DIR "/share/lives/"
 #define LIVES_CONFIG_DIR ".lives-dir/"
-#define LIVES_TMP_NAME "livestmp"
+#define LIVES_WORK_NAME "livesprojects"
 
 #else // IS_MINGW
 #define LIVES_DIR_SEP "\\"
@@ -220,7 +220,7 @@ typedef int lives_pgid_t;
 #define ICON_DIR "\\Icons/"
 #define DATA_DIR "\\Data/"
 #define LIVES_CONFIG_DIR "\\Config/"
-#define LIVES_TMP_NAME "livescache"
+#define LIVES_WORK_NAME "livesprojects"
 #endif
 
 #define LIVES_DEVICE_DIR "/dev/"
@@ -245,8 +245,7 @@ typedef int lives_pgid_t;
 #endif
 #endif
 
-#define DEF_FILE_PERMS (S_IRUSR|S_IWUSR) // must be at least S_IRUSR|S_IWUSR
-#define DEF_FILE_UMASK (S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH)^( DEF_FILE_PERMS )
+#define DEF_FILE_PERMS (S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH) ///< non-executable, is modified by the umask
 
 /// LiVES will show a warning if this (MBytes) is exceeded on load
 /// (can be overridden in prefs)
@@ -715,8 +714,8 @@ typedef struct {
   boolean smog_version_correct;
   boolean can_read_from_config;
   boolean can_write_to_config;
-  boolean can_write_to_tmp;
-  boolean can_write_to_tempdir;
+  boolean can_write_to_home;
+  boolean can_write_to_workdir;
 
   // the following may need checking before use
   boolean has_dvgrab;
@@ -742,9 +741,6 @@ typedef struct {
   /// home directory - default location for config file - locale encoding
   char home_dir[PATH_MAX];
 
-  /// system tempdir (e.g /tmp for linux, C:\TEMP for win32)
-  char system_tmpdir[PATH_MAX];  ///< kept in locale encoding
-
   char touch_cmd[PATH_MAX];
   char rm_cmd[PATH_MAX];
   char mv_cmd[PATH_MAX];
@@ -783,6 +779,8 @@ typedef struct {
 
   pid_t mainpid;
 
+  mode_t umask;
+
 } capability;
 
 
@@ -915,7 +913,7 @@ char *ds_critical_msg(const char *dir, uint64_t dsval);
 char *ds_warning_msg(const char *dir, uint64_t dsval, uint64_t cwarn, uint64_t nwarn);
 boolean check_storage_space(lives_clip_t *sfile, boolean is_processing);
 
-char *get_upd_msg(void);
+char *get_upd_msg(int type);
 char *get_new_install_msg(void);
 
 boolean ask_permission_dialog(int what);
@@ -923,7 +921,7 @@ boolean do_abort_check(void);
 void add_warn_check(LiVESBox *box, int warn_mask_number);
 void do_memory_error_dialog(void);
 void too_many_files(void);
-void tempdir_warning(void);
+void workdir_warning(void);
 void do_audio_import_error(void);
 void do_mt_backup_space_error(lives_mt *, int memreq_mb);
 
@@ -989,7 +987,7 @@ boolean do_existing_subs_warning(void);
 void do_invalid_subs_error(void);
 boolean do_erase_subs_warning(void);
 boolean do_sub_type_warning(const char *ext, const char *type_ext);
-boolean do_move_tmpdir_dialog(void);
+boolean do_move_workdir_dialog(void);
 void do_set_locked_warning(const char *setname);
 void do_no_in_vdevs_error(void);
 void do_locked_in_vdevs_error(void);
@@ -1081,6 +1079,7 @@ void set_signal_handlers(SignalHandlerPointer sigfunc);
 void catch_sigint(int signum);
 void defer_sigint(int signum);
 boolean startup_message_fatal(const char *msg);
+boolean startup_message_choice(const char *msg, int msgtype);
 boolean startup_message_nonfatal(const char *msg);
 boolean startup_message_info(const char *msg);
 boolean startup_message_nonfatal_dismissable(const char *msg, int warning_mask);
@@ -1298,7 +1297,7 @@ void clear_lmap_errors(void);
 boolean prompt_remove_layout_files(void);
 boolean do_std_checks(const char *type_name, const char *type, size_t maxlen, const char *nreject);
 boolean is_legal_set_name(const char *set_name, boolean allow_dupes);
-char *repl_tmpdir(const char *entry, boolean fwd);
+char *repl_workdir(const char *entry, boolean fwd);
 char *clip_detail_to_string(lives_clip_details_t what, size_t *maxlenp);
 boolean get_clip_value(int which, lives_clip_details_t, void *retval, size_t maxlen);
 void save_clip_value(int which, lives_clip_details_t, void *val);
